.. _api-repository:

============
Repositories
============

.. _api-repository-class:

.. autoclass:: protean.core.repository.BaseRepository

.. _api-repository-add:

``add()``
^^^^^^^^^^^^^^

.. automethod:: protean.core.repository.BaseRepository.add

.. _api-repository-remove:

``remove()``
^^^^^^^^^^^^^^

.. automethod:: protean.core.repository.BaseRepository.remove

.. _api-repository-get:

``get()``
^^^^^^^^^^^^^^

.. automethod:: protean.core.repository.BaseRepository.get
